ExoticFact

Trait ExoticFact 

pub trait ExoticFact:
    DynHash
    + DynEq
    + Send
    + Sync
    + Debug
    + DynClone
    + Downcast {
    // Required method
    fn buffer_sizes(&self) -> TVec<TDim>;

    // Provided methods
    fn compatible_with(&self, other: &dyn ExoticFact) -> bool { ... }
    fn clarify_dt_shape(&self) -> Option<(DatumType, TVec<TDim>)> { ... }
    fn mem_size(&self) -> TDim { ... }
}

Required Methods

Provided Methods

fn compatible_with(&self, other: &dyn ExoticFact) -> bool

Whether or not it is acceptable for a Patch to substitute self by other.

In other terms, all operators consuming self MUST accept also accept other without being altered.

fn clarify_dt_shape(&self) -> Option<(DatumType, TVec<TDim>)>

fn mem_size(&self) -> TDim

Implementations

Source

impl dyn ExoticFact

pub fn is<__T: ExoticFact>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: ExoticFact>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: ExoticFact>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: ExoticFact>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: ExoticFact>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.